/*
 * Copyright [2022] [https://www.baiduc.com]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.baiduc.com
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.baiduc.com
 */
package vip.xiaonuo.hr.modular.baseemployeeinfo.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.hr.modular.baseemployeeinfo.entity.HrBaseEmployeeInfo;
import vip.xiaonuo.hr.modular.baseemployeeinfo.mapper.HrBaseEmployeeInfoMapper;
import vip.xiaonuo.hr.modular.baseemployeeinfo.param.HrBaseEmployeeInfoAddParam;
import vip.xiaonuo.hr.modular.baseemployeeinfo.param.HrBaseEmployeeInfoEditParam;
import vip.xiaonuo.hr.modular.baseemployeeinfo.param.HrBaseEmployeeInfoIdParam;
import vip.xiaonuo.hr.modular.baseemployeeinfo.param.HrBaseEmployeeInfoPageParam;
import vip.xiaonuo.hr.modular.baseemployeeinfo.service.HrBaseEmployeeInfoService;

import java.util.List;

/**
 * 人员明细Service接口实现类
 *
 * @author 余
 * @date  2024/11/14 15:02
 **/
@Service
public class HrBaseEmployeeInfoServiceImpl extends ServiceImpl<HrBaseEmployeeInfoMapper, HrBaseEmployeeInfo> implements HrBaseEmployeeInfoService {

    @Override
    public Page<HrBaseEmployeeInfo> page(HrBaseEmployeeInfoPageParam hrBaseEmployeeInfoPageParam) {
        QueryWrapper<HrBaseEmployeeInfo> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(hrBaseEmployeeInfoPageParam.getSortField(), hrBaseEmployeeInfoPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(hrBaseEmployeeInfoPageParam.getSortOrder());
            queryWrapper.orderBy(true, hrBaseEmployeeInfoPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(hrBaseEmployeeInfoPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(HrBaseEmployeeInfo::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(HrBaseEmployeeInfoAddParam hrBaseEmployeeInfoAddParam) {
        HrBaseEmployeeInfo hrBaseEmployeeInfo = BeanUtil.toBean(hrBaseEmployeeInfoAddParam, HrBaseEmployeeInfo.class);
        this.save(hrBaseEmployeeInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(HrBaseEmployeeInfoEditParam hrBaseEmployeeInfoEditParam) {
        HrBaseEmployeeInfo hrBaseEmployeeInfo = this.queryEntity(hrBaseEmployeeInfoEditParam.getId());
        BeanUtil.copyProperties(hrBaseEmployeeInfoEditParam, hrBaseEmployeeInfo);
        this.updateById(hrBaseEmployeeInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<HrBaseEmployeeInfoIdParam> hrBaseEmployeeInfoIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(hrBaseEmployeeInfoIdParamList, HrBaseEmployeeInfoIdParam::getId));
    }

    @Override
    public HrBaseEmployeeInfo detail(HrBaseEmployeeInfoIdParam hrBaseEmployeeInfoIdParam) {
        return this.queryEntity(hrBaseEmployeeInfoIdParam.getId());
    }

    @Override
    public HrBaseEmployeeInfo queryEntity(String id) {
        HrBaseEmployeeInfo hrBaseEmployeeInfo = this.getById(id);
        if(ObjectUtil.isEmpty(hrBaseEmployeeInfo)) {
            throw new CommonException("人员明细不存在，id值为：{}", id);
        }
        return hrBaseEmployeeInfo;
    }
}
